TCFlib
======

TCFlib is a Python API for working with linguistic annotations using the [TCF] file format and the [WebLicht] environment.

TCFlib supports annotating files using local and remote annotation services and writing new annotation services.

Note: The API is not final, yet. Feedback and patches are highly welcome!

Installation
------------

TCFlib is available from PyPI, so you can install it with pip:

    pip install tcflib

You can install the development version directly from GitHub:

    pip install git+https://github.com/SeNeReKo/TCFlib.git

Documentation
-------------

Documentation is available from <http://tcflib.readthedocs.org/>.

[TCF]: http://weblicht.sfs.uni-tuebingen.de/weblichtwiki/index.php/The_TCF_Format
[WebLicht]: http://weblicht.sfs.uni-tuebingen.de/weblichtwiki/index.php/Main_Page

